==> message-facade-2.0.5-20211122.082234-4-sources.jar: com/bizvane/messagefacade/interfaces/SendPointMsgServiceFeign.java <==
package com.bizvane.messagefacade.interfaces;

import com.bizvane.messagefacade.models.dto.ExpirePointMemebersVO;
import com.bizvane.messagefacade.models.vo.ClearPointVO;
import com.bizvane.messagefacade.models.vo.ExpirePointSearchVO;
import com.bizvane.messagefacade.models.vo.ExpirePointVO;
import com.bizvane.utils.responseinfo.ResponseData;
import com.github.pagehelper.PageInfo;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import java.util.List;

/**
 * 获取短信模板
 * @author Bizvane
 */
@FeignClient(value = "${feign.client.message.name}", path = "${feign.client.message.path}/pointMsg")
public interface SendPointMsgServiceFeign {

    /**
     *  积分过期消息通知
     * @param expirePointVO
     * @return
     */
    @PostMapping(value = "/sendTemplateMsg")
    ResponseData<String> sendMsg(@RequestBody ExpirePointVO expirePointVO);

    /**
     *  查询积分过期会员信息
     * @param expirePointSearchVO
     * @return
     */
    @PostMapping(value = "/searchMsgRecord")
    ResponseData<PageInfo<ExpirePointMemebersVO>> searchMsgRecord(@RequestBody ExpirePointSearchVO expirePointSearchVO);


    /**
     *  查询积分过期会员信息
     * @param cleatPointVO
     * @return
     */
    @PostMapping(value = "/searchClearPointSendFail")
    ResponseData<List<String>> searchClearPointSendFail(@RequestBody ClearPointVO cleatPointVO);
    /**
     *  查询积分过期会员信息
     * @param cleatPointVO
     * @return
     */
    @PostMapping(value = "/sendPointClearMsg")
    ResponseData<String> sendPointClearMsg(@RequestBody ClearPointVO cleatPointVO);


}

==> message-facade-2.0.5-20211123.031326-6-sources.jar: com/bizvane/messagefacade/interfaces/SendPointMsgServiceFeign.java <==
package com.bizvane.messagefacade.interfaces;

import com.bizvane.messagefacade.models.dto.ExpirePointMemebersVO;
import com.bizvane.messagefacade.models.vo.ClearPointVO;
import com.bizvane.messagefacade.models.vo.ExpirePointSearchVO;
import com.bizvane.messagefacade.models.vo.ExpirePointVO;
import com.bizvane.utils.responseinfo.ResponseData;
import com.github.pagehelper.PageInfo;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * 获取短信模板
 * @author Bizvane
 */
@FeignClient(value = "${feign.client.message.name}", path = "${feign.client.message.path}/pointMsg")
public interface SendPointMsgServiceFeign {

    /**
     *  积分过期消息通知
     * @param expirePointVO
     * @return
     */
    @PostMapping(value = "/sendTemplateMsg")
    ResponseData<String> sendMsg(@RequestBody ExpirePointVO expirePointVO);

    /**
     *  查询积分过期会员信息
     * @param expirePointSearchVO
     * @return
     */
    @PostMapping(value = "/searchMsgRecord")
    ResponseData<PageInfo<ExpirePointMemebersVO>> searchMsgRecord(@RequestBody ExpirePointSearchVO expirePointSearchVO);


    /**
     *  查询积分过期会员信息
     * @param cleatPointVO
     * @return
     */
    @PostMapping(value = "/searchClearPointSendFail")
    ResponseData<List<String>> searchClearPointSendFail(@RequestBody ClearPointVO cleatPointVO);
    /**
     *  查询积分过期会员信息
     * @param cleatPointVO
     * @return
     */
    @PostMapping(value = "/sendPointClearMsg")
    ResponseData<String> sendPointClearMsg(@RequestBody ClearPointVO cleatPointVO);

    /**
     *  检验是否存在有效通知模板（微信或短信任意一个有效）
     * @param sysBrandId
     * @param templateType
     * @return
     */
    @PostMapping(value = "/searchMsgTemplateExist")
    ResponseData<Boolean> searchMsgTemplateExist(@RequestParam("sysBrandId")Long sysBrandId, @RequestParam("templateType")String templateType);

}
